/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include <QApplication>
#include <QFile>

#include "DatabaseInterface.h"
#include "SetupWizard.h"
#include "MainWindow.h"

/**
 *
 */
int main( int argc, char* argv[] )
{
	QApplication app( argc, argv );

	// DATABASE SETUP TEST CODE
	DatabaseInterface dbInterface;
	dbInterface.open();

	bool setupDB = false;

	if ( setupDB )
	{
		// Create tables
		dbInterface.exec( QString("CREATE TABLE Lessons ( LessonID INTEGER, Author VARCHAR(40), Email VARCHAR(40), XMLPath VARCHAR(255), Created DATETIME, QuestionCount INTEGER, PRIMARY KEY (LessonID));" ) );
		dbInterface.exec( QString("CREATE TABLE TakenLessons ( LessonID INTEGER, LangID VARCHAR(3), ResultID INTEGER, DateTaken DATETIME, PRIMARY KEY (LessonID, LangID, ResultID, DateTaken), FOREIGN KEY (LessonID) REFERENCES Lessons(LessonID), FOREIGN KEY (LangID) REFERENCES LanguageCodes(LangID), FOREIGN KEY (ResultID) REFERENCES Results(ResultID));" ) );
		dbInterface.exec( QString("CREATE TABLE Results ( ResultID INTEGER, QuestionNum INTEGER, result INTEGER, PRIMARY KEY (ResultID, QuestionNum) );" ) );
		dbInterface.exec( QString("CREATE TABLE LessonLanguages ( LessonID INTEGER, LangID VARCHAR(3), Title VARCHAR(40), Description VARCHAR(500), PRIMARY KEY (LessonID, LangID),FOREIGN KEY (LessonID) REFERENCES Lessons(LessonID),FOREIGN KEY (LangID) REFERENCES LanguageCodes(LangID));" ) );
		
		dbInterface.exec( QString("INSERT INTO Lessons VALUES ( NULL,'Jon Black','juan.black@gmail.com','lessons/numbers.vocml','07/09/2006','10');" ) );
		dbInterface.exec( QString("INSERT INTO Lessons VALUES ( NULL,'Jon Black','juan.black@gmail.com','lessons/family.vocml','17/09/2006','11');" ) );
		//dbInterface.exec( QString("INSERT INTO Lessons VALUES ( NULL,'Jon Black','juan.black@gmail.com','lessons/farmanimals.vocml','07/09/2006','10');" ) );
		//dbInterface.exec( QString("INSERT INTO Lessons VALUES ( NULL,'Jon Black','juan.black@gmail.com','lessons/bodyparts.vocml','17/09/2006','15');" ) );
		//dbInterface.exec( QString("INSERT INTO Lessons VALUES ( NULL,'Jon Black','juan.black@gmail.com','lessons/insects.vocml','17/09/2006','10');" ) );

		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '1','eng','Numbers','learn numbers');" ) );
		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '1','spa','Numeros','aprendre les nombres');" ) );		
		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '1','fra','Nombres','aprender los numeros');" ) );
		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '2','eng','Family Members','Names for the different members of the family.');" ) );
		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '2','spa','Los Miembros de la Familia','Nombres de los varios miembros de la familia.');" ) );		
		dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '2','fra','Les Membres de la Famille','Noms des differents membres de la famille.');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '3','eng','Farm Animals','Animals that you find on a farm');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '3','spa','Los Animales de la Granja','Animales que se encuentran en la granja');" ) );		
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '3','fra','Les Animaux de la Ferme','Animaux que l''on trouve à la ferme');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '4','eng','Body Parts','Parts of the Human Body');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '4','spa','Les Parties du Corps','Los Miembros del Ser Humano');" ) );		
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '4','fra','Las Partes del Cuerpo','Les Membres du Corps Humain');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '5','eng','Colours','Names of Colours');" ) );
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '5','spa','Colores','Los Nombres de los Colores');" ) );		
		//dbInterface.exec( QString("INSERT INTO LessonLanguages VALUES ( '5','fra','Couleurs','les noms des Couleurs');" ) );	
	}

	// 1. Show setup wizard if .ini file doesn't exist
	
	if ( ! QFile::exists( "gibberish.ini" ) )
	{
		SetupWizard * uiSetup = new SetupWizard();
		
		if ( uiSetup->exec() == QDialog::Rejected )
			return 0;
	}

	MainWindow * uiMain = new MainWindow;
	uiMain->show();

	return app.exec();
}
