/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include <QtDebug>

#include "LessonWidget.h"
#include "Questions.h"

// *****************************************************************************
// Constructor/Destructor
// *****************************************************************************

/**
 *
 */
LessonWidgetMC::LessonWidgetMC( QWidget * parent )
	: LessonWidget( parent )
{
	setupUi( this );

	// Set the instructions text
	instructions = "<h1>Multiple Choice</h1>";
	instructions += "<h2>Instructions</h2>";
	instructions += "<p>";
	instructions += "Each question is displayed with three possible answers, only one of which is correct.";
	instructions += "</p>";
	instructions += "<h2>Aim</h2>";
	instructions += "<p>";
	instructions += "Select the correct translation from the three answers to score.";
	instructions += "</p>";
}

// *****************************************************************************
// Methods
// *****************************************************************************

/**
 *
 */
void LessonWidgetMC::nextQuestion( Questions * lQuestions )
{
	QString question;
	QString answer1;
	QString answer2;
	QString answer3;

	// Get the question
	lQuestions->getNextQuestion( question );

	// Generate random number for the position of the answer
	answerPos = lQuestions->generateRandomNumber( 1, 4 );

	qDebug() << "Answer Position:" << answerPos;

	bool isUniqueSet = false;

	while ( !isUniqueSet ) 
	{
		isUniqueSet = true;

		switch ( answerPos )
		{
			case 1:
				answerNumberLiteral1 = lQuestions->getNextAnswer( answer1 );
				answerNumberLiteral2 = lQuestions->getAnyAnswer( answer2 );
				answerNumberLiteral3 = lQuestions->getAnyAnswer( answer3 );
				break;
			case 2:
				// Set the text
				answerNumberLiteral1 = lQuestions->getAnyAnswer( answer1 );	
				answerNumberLiteral2 = lQuestions->getNextAnswer( answer2 );
				answerNumberLiteral3 = lQuestions->getAnyAnswer( answer3 );
				break;
			case 3:
				// Set the text
				answerNumberLiteral1 = lQuestions->getAnyAnswer( answer1 );
				answerNumberLiteral2 = lQuestions->getAnyAnswer( answer2 );
				answerNumberLiteral3 = lQuestions->getNextAnswer( answer3 );
				break;
		}
	
		//qDebug() << "a1:" << answerNumberLiteral1;
		//qDebug() << "a2:" << answerNumberLiteral2;
		//qDebug() << "a3:" << answerNumberLiteral3;

		if ( answerNumberLiteral1 == answerNumberLiteral2 )
			isUniqueSet = false;
		else if ( answerNumberLiteral2 == answerNumberLiteral3 )
			isUniqueSet = false;
		else if ( answerNumberLiteral1 == answerNumberLiteral3 )
			isUniqueSet = false;
	}

	// Set the question & answer text
	qlQuestion->setText( question );
	qrbAnswer1->setText( answer1 );
	qrbAnswer2->setText( answer2 );
	qrbAnswer3->setText( answer3 );
}

/**
 * \fn checkAnswer
 * \brief Used to check if the answer was correct
 * \return Whether the answer was correct
 * 
 * This method must be implemented to return whether or not
 * the selected answer, by whatever means, was correct or not
 * and return that as a bool.
 */
bool LessonWidgetMC::checkAnswer( Questions * lQuestions )
{
	int answer = 0;

	// Check if the answer was correct
	if ( qrbAnswer1->isChecked() )
	{
		answer = 1;
		answerGiven = answerNumberLiteral1;
	}
	else if ( qrbAnswer2->isChecked() )
	{
		answer = 2;
		answerGiven = answerNumberLiteral2;
	}
	else if ( qrbAnswer3->isChecked() )
	{
		answer = 3;
		answerGiven = answerNumberLiteral3;
	}

	if ( answer == answerPos )
		return true;
	else
		return false;
}
