/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

/**
 * \file Questions.cpp
 * \author Jon Black
 */ 

#include "Questions.h"
//#include <cstdlib> 
//#include <ctime> 

// *****************************************************************************
// Constructor/Destructor
// *****************************************************************************

/**
 *
 */
Questions::Questions()
{
	questionNumberLiteral = 0;
	questionNumberCount = 0;
	std::srand( (unsigned) time(0) );
}

// *****************************************************************************
// Methods
// *****************************************************************************

/**
 *
 */
void Questions::addQuestion( QString question )
{
	questions.append( question );
}

/**
 *
 */
void Questions::addAnswer( QString answer )
{
	answers.append( answer );
}

/** \fn getNextQuestion
 * \brief Gets the next question that hasn't been asked already
 * \param question Pointer to a QString to store the question
 * \return The literal question number in the set
 *
 * This function will get the next question from the set that hasn't already been
 * asked. It stores the question is finds in QString pointer to by the parameter
 * and returns the literal question number in the set that the question corresponds
 * to.
 */
int Questions::getNextQuestion( QString & question )
{
	// Increase number of questions that have been asked
	questionNumberCount++;
	//qDebug() << "Incremented Question Number. Question Number is:" << questionNumberCount;

	// Get a unique question number
	questionNumberLiteral = generateQuestionNumber();
	//qDebug() << "generate question number";
	
	// Set this question number as used
	questionsAsked.append( questionNumberLiteral );
	//qDebug() << "set question number as used";

	// Add this question number to the question odering
	//questionOrder.append( questionNumberLiteral );

	// Set the passed QString
	question = questions.at( questionNumberLiteral );

	return questionNumberLiteral;
}

/** \fn getNextAnswer
 * \brief Gets the answer to the question that was last asked
 * \param answer Pointer to a QString to store the answer
 * \return The literal answer number in the set
 *
 */
int Questions::getNextAnswer( QString& answer )
{
	answer = answers.at( questionNumberLiteral );

	return questionNumberLiteral;
}

/** \fn getAnyQuestion
 * \brief Gets any question in the set regardless of whether it has already been asked
 * \param question Pointer to a QString to store the answer
 * \return The literal question number in the set
 *
 */
int Questions::getAnyQuestion( QString& question )
{
	// Get a unique question number
	int anyQNum = generateRandomNumber( 1, questions.size() );
	
	// Return the question string
	question = questions.at( anyQNum );

	return anyQNum;
}

/** \fn getAnyAnswer
 * \brief Gets any answer from the answer set regardless of what question was asked
 * \param answer Pointer to a QString to store the answer
 * \return The literal answer number in the set
 *
 */
int Questions::getAnyAnswer( QString& answer )
{
	// Get a unique question number
	int anyANum = generateRandomNumber( 0, questions.size() );
	
	// Return the question string
	answer = answers.at( anyANum );

	return anyANum;
}

/**
 * Resets the questions so that none have been asked
 *
 */
void Questions::reset()
{
	
}

/**
 * Generates a random number between min and max.
 *
 * \param min the lowest number to produce
 * \param max the highest number to produce
 * \return the random number that was generated 
 */
int Questions::generateRandomNumber( int min, int max )
{
	return ( std::rand() % ( max - min ) ) + min;
}

/**
 *
 */
int Questions::generateQuestionNumber()
{
	//qDebug() << "Questions::generateQuestionNumber()";
	bool isUnique = false;
	int pNumber;
	int safety = 0;

	while ( !isUnique )
	{
		safety++;

		pNumber = generateRandomNumber( 1, questions.size() );

		//qDebug() << "Random number is" << pNumber;

		if ( questionsAsked.contains( pNumber ) )
			isUnique = false;
		else
			isUnique = true;

		//qDebug() << "Has this been asked before?" << isUnique;

		if ( safety > 100 )
		{
			//qDebug() << "safety caught it";
			return 1;
		}
	}

	return pNumber;
}
