/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include <QSqlQuery>
#include <QSettings>

#include "SetupWizard.h"
#include "DatabaseInterface.h"

/**
 *
 */
SetupWizard::SetupWizard( QWidget* parent )
	: QDialog( parent )
{
	setupUi( this );

	DatabaseInterface dbInterface;
	
	QString sql = QString( "SELECT LangID, Name FROM LanguageCodes WHERE LangStatus<>'E' ORDER BY Name;" );
	QSqlQuery* query = dbInterface.exec( sql );

	if ( query->isActive() )
	{
		while ( query->next() ) 
		{
			QListWidgetItem * wItem = new QListWidgetItem( query->value(1).toString(), wLanguages );
			wItem->setData( Qt::UserRole, QString( query->value(0).toString() ) );
		}
	}
}

/**
 *
 */
void SetupWizard::on_wOK_clicked()
{
	// 1. Write settings file

	QSettings settings("gibberish.ini", QSettings::IniFormat);

	settings.beginGroup( "StudentProfile" );
	settings.setValue( "forename", wForename->text() );
	settings.setValue( "surname", wSurname->text() );

	QStringList items;

	for ( int i = 0; i < wNativeLanguages->count(); i++ )
		items.append( wNativeLanguages->item( i )->data( Qt::UserRole ).toString() );
	settings.setValue( "currentnativelanguage", items.at(0) );
	settings.setValue( "nativelanguages", items.join("+") );

	items.clear();

	for ( int i = 0; i < wStudyLanguages->count(); i++ )
		items.append( wStudyLanguages->item( i )->data( Qt::UserRole ).toString() );
	settings.setValue( "currentstudylanguage", items.at(0) );
	settings.setValue( "studylanguages", items.join("+") );

	settings.endGroup();

	accept();	
}

/**
 *
 */
void SetupWizard::on_wFilter_textChanged( const QString & text )
{
	QList<QListWidgetItem*> wFoundItems = wLanguages->findItems( text, Qt::MatchStartsWith );

	if ( wFoundItems.size() > 0 )
		wLanguages->scrollToItem( wFoundItems.at(0), QAbstractItemView::PositionAtTop );
}

/**
 *
 */
void SetupWizard::on_wAddNativeLanguage_clicked()
{
	int row = wLanguages->currentRow();

	if ( row > -1 )
		wNativeLanguages->addItem( wLanguages->takeItem( row ) );
}

/**
 *
 */
void SetupWizard::on_wRemoveNativeLanguage_clicked()
{
	int row = wNativeLanguages->currentRow();

	if ( row > -1 )
		wLanguages->addItem( wNativeLanguages->takeItem( row ) );
}

/**
 *
 */
void SetupWizard::on_wAddStudyLanguage_clicked()
{
	int row = wLanguages->currentRow();

	if ( row > -1 )
		wStudyLanguages->addItem( wLanguages->takeItem( row ) );
}

/**
 *
 */
void SetupWizard::on_wRemoveStudyLanguage_clicked()
{
	int row = wStudyLanguages->currentRow();

	if ( row > -1 )
		wLanguages->addItem( wStudyLanguages->takeItem( row ) );
}
