/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include "TimerWidget.h"

#include <QTimer>

/**
 *
 */
TimerWidget::TimerWidget( QWidget * parent )
	: QWidget( parent )
{
	setupUi( this );

	lTimer = new QTimer;

	connect( lTimer, SIGNAL( timeout() ), this, SLOT( updateTimer() ) );
}

void TimerWidget::setTime( QTime time )
{
	//qDebug() << "Timer set";
	this->timeLimit = time;
	this->timeRem = time;

	qlcdTimer->display( timeRem.toString( "mm:ss" ) );
	int totalSeconds = ( timeLimit.minute() * 60 ) + timeLimit.second();
	qprTimer->setRange( 0, totalSeconds  );
	qprTimer->setValue( totalSeconds );
}

void TimerWidget::startTimer()
{
	//qDebug() << "Timer started";
	lTimer->start( 1000 ); // Start the timer so it fires every 1 sec
}

void TimerWidget::pauseTimer()
{
	//qDebug() << "Timer paused";
	lTimer->stop();
}

void TimerWidget::resetTimer()
{
	//qDebug() << "Timer reset";
	timeRem = timeLimit;
}

void TimerWidget::updateTimer()
{
	timeRem = timeRem.addSecs( -1 ); // Reduce time by a second

	int totalSeconds = ( timeLimit.minute() * 60 ) + timeLimit.second();
	int remSeconds = ( timeRem.minute() * 60 ) + timeRem.second();
	qprTimer->setRange( 0, totalSeconds  );
	qprTimer->setValue( remSeconds );

	//qDebug() << "Time:" << timeRem.toString( "mm:ss" );

	if ( timeRem.minute() == 0 && timeRem.second() == 0 && timeRem.msec() == 0 )
	{
		//qDebug() << "Time up";
		qlcdTimer->display( timeRem.toString( "mm:ss" ) );
		lTimer->stop();
		emit timeUp(); // Ran out of time!
	}
	else
	{
		//qDebug() << "Timer updated";
		qlcdTimer->display( timeRem.toString( "mm:ss" ) );
	}
}
