/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include "VocabularyParser.h"
#include "Questions.h"

// *****************************************************************************
// Constructor/Destructor
// *****************************************************************************

/**
 *
 */
VocabularyParser::VocabularyParser( QString nLang, QString fLang )
{
	nativeLang = nLang;
	foreignLang = fLang;
}

// *****************************************************************************
// Methods
// *****************************************************************************

/**
 *
 */
void VocabularyParser::parse( QIODevice* device, Questions* lQuestions )
{
	this->lQuestions = lQuestions;

  QString errorStr;
  int errorLine;
  int errorColumn;
  QDomDocument doc;

	bool contentSet = doc.setContent( device, true, &errorStr, &errorLine, &errorColumn );

	if ( !contentSet )
	{
		//qDebug() << "Parse error at line:" << errorLine << "column:" << errorColumn << "str:" << errorStr;
		return;
	}

	QDomElement root = doc.documentElement();

	if ( root.tagName() != "vocabulary" )
	{
			//qDebug() << "[XML ERROR] No <vocabulary> tag";
			return;
	}

	QDomNode node = root.firstChild();

	while ( !node.isNull() ) 
	{
		//qDebug() << "Found:" << node.toElement().tagName();
		if ( node.toElement().tagName() == "words" )
		{
				//qDebug() << "Found <words> tag. Parsing.";
				parseWords( node.toElement() );
		}
		
		node = node.nextSibling();
	}
}


/**
 *
 */
void VocabularyParser::parseWords( const QDomElement &element )
{
	QDomNode node = element.firstChild();

	while ( !node.isNull() ) 
	{
		if ( node.toElement().tagName() == "entry" ) 
		{
			//qDebug() << "Found <entry> tag. Parsing.";		
			parseEntry( node.toElement() );
		}

		node = node.nextSibling();
	}
}

/**
 *
 */
void VocabularyParser::parseEntry( const QDomElement &element )
{
	QDomNode node = element.firstChild();

	while ( !node.isNull() ) 
	{
		if ( node.toElement().tagName() == "tr" ) 
		{
				QDomElement trElement = node.toElement();

				//qDebug() << "Found <tr> tag. Parsing.";

				if ( trElement.attribute( "lang" ) == nativeLang )
				{
					//qDebug() << "Found eng lang attribute";					

					QDomNode childNode = node.firstChild();

					if ( childNode.nodeType() == QDomNode::TextNode )
					{
						QString question = childNode.toText().data();
						lQuestions->addQuestion( question );
						//qDebug() << "Added question:" << question;
					}
				}				
				else if ( trElement.attribute( "lang" ) == foreignLang )
				{
				 	//qDebug() << "Found fra lang attribute";

					QDomNode childNode = node.firstChild();

					if ( childNode.nodeType() == QDomNode::TextNode )
					{
						QString answer = childNode.toText().data();
						lQuestions->addAnswer( answer );
						//qDebug() << "Added answer:" << answer;
					}
				}
		}

		node = node.nextSibling();
	}
}
