/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

/**
 * \file Lesson.h
 * \author Jon Black
 */

#ifndef LESSON_H
#define LESSON_H

#include <QString>

class LessonSettings;
class Questions;
class Score;

/** 
 * \class Lesson 
 * \brief Responsible for the lesson
 *
 * This class encapsulates everything relevant to a lesson. This includes
 * the settings, questions and score. 
 * 
 * This is the single entry point for information regarding a lesson.
 */
class Lesson
{
	public:
		Lesson();
		Lesson( QString title );

		void setLessonID( int ID );
		void setTitle( QString title );
		void setInstructions( QString instructions );
		void setLessonSettings( LessonSettings * lSettings );
		void setQuestions( Questions * lQuestions );

		int getLessonID();
		QString getTitle();
		QString getInstructions();
		LessonSettings * getLessonSettings();
		Questions * getQuestions();
		Score * getScore();

	private:
		int lessonID;
		QString title;
		QString instructions;
		Score * lScore;
		Questions * lQuestions;
		LessonSettings * lSettings;
};

#endif
