/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

/**
 * \file LessonSettings.h
 * \author Jon Black
 */ 

#ifndef LESSONSETTINGS_H
#define LESSONSETTINGS_H

#include <QTime>

/** 
 * \class LessonSettings 
 * \brief Responsible for the lesson settings
 *
 * The score class is responsible for the lesson settings. This
 * includes a lot of optional lesson information. The list is:
 *				- Lesson type;
 *				- Time limit;
 *
 */
class LessonSettings
{
	public:
		LessonSettings();

		void setNativeLang( QString nLang );
		void setForeignLang( QString fLang);
		void setLessonType( int lType );
		void setTime( QTime time );
		void setNativeFirst( bool isNativeFirst );
		void setUseTimer( bool useTimer );	

		inline bool isUseTimer() const { return useTimer; };
		inline bool isNativeFirst() const { return nativeFirst; };
		inline QTime getTime() const { return time; };
		inline QString getNativeLang() const { return nativeLang; };
		inline QString getStudyLang() const { return studyLang; };
		inline int getLessonType() const { return lType; };

	private:
		int lType;
		QString nativeLang;
		QString studyLang;
		QTime time;
		bool nativeFirst;
		bool useTimer;
};

#endif
