/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef LESSONWIDGET_H
#define LESSONWIDGET_H

#include <QWidget>

class Questions;

/** 
 * \class LessonWidget 
 * \brief Abstract widget class for displaying a lesson
 */
class LessonWidget : public QWidget
{
	Q_OBJECT

	public:
		LessonWidget( QWidget * parent = 0 );

		inline int getAnswerGiven() const { return answerGiven; };
		inline QString getInstructions() const { return instructions; };

	public slots:
		virtual void pauseLesson();
		virtual void endLesson();
		virtual bool checkAnswer( Questions * lQuestions ) = 0;
		virtual void nextQuestion( Questions * lQuestions ) = 0;

	private:
		int currentSelectedAnswer();

	protected:
		int answerGiven;
		QString instructions;
};

#include "ui_LessonWidgetFC.h"

/** 
 * \class LessonWidgetFC
 * \brief Flash card version of the LessonWidget
 */
class LessonWidgetFC : public LessonWidget, private Ui::LessonWidgetFC
{
	Q_OBJECT

	public:
		LessonWidgetFC( QWidget* parent = 0 );
		
	public slots:
		virtual bool checkAnswer( Questions * lQuestions );
		virtual void nextQuestion( Questions * lQuestions );

};

#include "ui_LessonWidgetMC.h"

/** 
 * \class LessonWidgetMC
 * \brief Multiple Choice version of the Lesson Widget
 */
class LessonWidgetMC : public LessonWidget, private Ui::LessonWidgetMC
{
	Q_OBJECT

	public:
		LessonWidgetMC( QWidget * parent = 0 );

	public slots:
		virtual bool checkAnswer( Questions * lQuestions );
		virtual void nextQuestion( Questions * lQuestions );

	private:
		int answerPos; 						///< Radio button that has the correct answer
		int answerNumberLiteral1;	///< Holds the literal answer number at position 1
		int answerNumberLiteral2;	///< Holds the literal answer number at position 2
		int answerNumberLiteral3;	///< Holds the literal answer number at position 3
};

#include "ui_LessonWidgetQA.h"

/** 
 * \class LessonWidgetQA
 * \brief Question and Answer version of the LessonWidget
 */
class LessonWidgetQA : public LessonWidget, private Ui::LessonWidgetQA
{
	Q_OBJECT

	public:
		LessonWidgetQA( QWidget* parent = 0 );

	public slots:
		virtual bool checkAnswer( Questions * lQuestions );
		virtual void nextQuestion( Questions * lQuestions );
};

#endif
