/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

/**
 * \file Questions.h
 * \author Jon Black
 */ 

#ifndef QUESTIONS_H
#define QUESTIONS_H

#include <QList>
#include <QString>

/** 
 * \class Questions 
 * \brief Responsible for the lesson questions and answers
 *
 * The score class is responsible for both the questions and the
 * answers that will be presented to the student during a lesson.
 *
 * In addition to this, the class is also responsible for tracking:
 *				- The order in which the questions were asked;
 *				- The questions that have been asked;
 *				- Generating the next question to ask;
 */
class Questions
{
	public:
		Questions();

		void addQuestion( QString question );
		void addAnswer( QString answer );
		void reset();

		int getNextQuestion( QString & question );
		int getNextAnswer( QString & answer );
		int getAnyQuestion( QString & question );
		int getAnyAnswer( QString & answer );

		inline int getQuestionNumberCount() const { return questionNumberCount; };
		inline int getQuestionNumberLiteral() const { return questionNumberLiteral; };
		inline int getQuestionNumberTotal() const { return questions.size(); };
		inline QList<QString> getQuestions() const { return questions; };
		inline QList<QString> getAnswers() const { return answers; };
		inline QList<int> getQuestionsAsked() const { return questionsAsked; };

		int generateRandomNumber( int min, int max ); // TODO Move to a utility class??

	private:
		int questionNumberLiteral;	///< Literal question number in question set used to get answer
		int questionNumberCount;		///< Sequence question number in lesson
		QList<QString> questions;		///< Lesson questions
		QList<QString> answers;			///< Lesson answers
		QList<int> questionsAsked;	///< Questions that have been asked

		int generateQuestionNumber();

};

#endif
