/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#include "LineChart.h"

#include <QPainter>
#include <QDebug>
#include <QPen>

/**
 *
 */
LineChart::LineChart( QWidget * parent )
	: QWidget( parent )
{
	setBackgroundRole( QPalette::Dark );
	setAutoFillBackground( true );

	setXMaxVal( 10 );
	setYMaxVal( 10 );
  setGlobalMargin( 10 );

	gridColour.setRgb( 100, 100, 100 );
	axisColour.setRgb( 150, 150, 150 );
	dataColour.setRgb( 0, 200, 0 );

	gridLineWidth = 1;
	axisLineWidth = 1;
	dataLineWidth = 1;

	gridWidth		= 0;
	gridHeight	= 0;
	gridX1			= 0;
	gridY1			= 0;
	gridX2			= 0;
	gridY2			= 0;
	xSegments		= 0;
	ySegments		= 0;
	xSpacing		= 0;
	ySpacing		= 0;	
}

/**
 *
 */
void LineChart::paintEvent(QPaintEvent *event)
{
	QPainter painter( this );
	
	gridWidth		= width()  - globalMargin * 2;
	gridHeight	= height() - globalMargin * 2;
	gridX1 			= globalMargin;
	gridY1 			= globalMargin;
	gridX2 			= width()  - globalMargin;
	gridY2 			= height() - globalMargin;
	xSegments 	= xMaxVal + 1;
	ySegments 	= yMaxVal + 1;
	xSpacing 		= gridWidth  / xSegments;
	ySpacing 		= gridHeight / ySegments;

	//qDebug() << "xSpacing:" << xSpacing;
	//qDebug() << "ySpacing:" << ySpacing;
	//qDebug() << "Width:" << width();
	//qDebug() << "Height:" << height();
	//qDebug() << "Grid Height:" << gridHeight;
	//qDebug() << "Grid Width:"  << gridWidth;

	// 1. Draw Grid

	painter.setPen( QPen( gridColour, gridLineWidth ) );

	for ( double i = 1.0; i <= xMaxVal; i++ ) // x-axis lines
	{
		QLineF line( gridX1 + ( i * xSpacing ), gridY1, gridX1 + ( i * xSpacing ), gridY2 );
		painter.drawLine( line  );
	}
	
	for ( double i = 1.0; i <= yMaxVal + 1; i++ ) // y-axis lines
	{
		QLineF line( gridX1, gridY1 + ( i * ySpacing ), gridX2, gridY1 + ( i * ySpacing ) );
		painter.drawLine( line );
	}

	// 2. Draw Data Line

	calculateDataPoints();
	painter.setPen( QPen( dataColour, dataLineWidth ) ); 
	painter.drawPolyline( dataPoints, numDataPoints );

	// 3. Draw Outline

	painter.setPen( QPen( axisColour, axisLineWidth ) );
	QRectF rect( gridX1, gridY1, gridWidth, gridHeight );
	painter.drawRect( rect );
}

/**
 *
 */
void LineChart::setGlobalMargin( int globalMargin )
{
	this->globalMargin = globalMargin;
}

/**
 *
 */
void LineChart::setDataPointsList( QList<double> dataPointsList )
{
	this->dataPointsList = dataPointsList;

	update();
}

/**
 *
 */
void LineChart::calculateDataPoints()
{
	// 1. Convert this list of data points to a QPointF array
	
	numDataPoints = dataPointsList.size();
	dataPoints = new QPointF[numDataPoints];

	for ( int i = 0; i < numDataPoints; i++ )
	{
		//qDebug() << "Point" << i+1 << " = " << dataPointsList.at(i);
		QPointF dp( gridX1 + ( xSpacing * (i+1)  ), gridY2 - ( ySpacing * dataPointsList.at(i)  ) );
		dataPoints[i] = dp;
	}
}

/**
 *
 */
void LineChart::setXMaxVal( int mx )
{
	xMaxVal = mx;
}

/**
 *
 */
void LineChart::setYMaxVal( int my )
{
	yMaxVal = my;
}

/**
 *
 */
int LineChart::getGlobalMargin()
{
	return globalMargin;
}

void LineChart::setGridColour( QColor colour )
{
	gridColour = colour;
}

void LineChart::setAxisColour( QColor colour )
{
	axisColour = colour;
}

void LineChart::setDataColour( QColor colour )
{
	dataColour = colour;
}

int LineChart::getXMaxVal()
{
	return xMaxVal;
}

int LineChart::getYMaxVal()
{
	return yMaxVal;
}

QColor LineChart::getGridColour()
{
	return gridColour;
}

QColor LineChart::getAxisColour()
{
	return axisColour;
}

QColor LineChart::getDataColour()
{
	return dataColour;
}
