/******************************************************************************
 *
 * Copyright (c) 2006 Jon Black
 *
 * This file is part of Gibberish.
 *
 * Gibberish is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * Gibberish is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Foobar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *****************************************************************************/

#ifndef _H_LINE_CHART
#define _H_LINE_CHART

#include <QPaintEvent>
#include <QColor>
#include <QWidget>

class LineChart : public QWidget
{
	Q_OBJECT
	Q_PROPERTY( int globalMargin READ getGlobalMargin WRITE setGlobalMargin )
	Q_PROPERTY( int xMaxVal READ getXMaxVal WRITE setXMaxVal )
	Q_PROPERTY( int yMaxVal READ getYMaxVal WRITE setYMaxVal )
	Q_PROPERTY( QColor gridColour READ getGridColour WRITE setGridColour )
	Q_PROPERTY( QColor axisColour READ getAxisColour WRITE setAxisColour )
	Q_PROPERTY( QColor dataColour READ getDataColour WRITE setDataColour )

	public:
		LineChart( QWidget * parent = 0 );

		void setGlobalMargin( int globalMargin );
		void setDataPointsList( QList<double> dataPoints );
		void setXMaxVal( int mx );
		void setYMaxVal( int my );
		void setGridColour( QColor colour );
		void setAxisColour( QColor colour );
		void setDataColour( QColor colour );

		int getGlobalMargin();
		int getXMaxVal();
		int getYMaxVal();
		QColor getGridColour();
		QColor getAxisColour();
		QColor getDataColour();

	protected:
    void paintEvent( QPaintEvent *event );

	private:
		int xMaxVal;
		int yMaxVal;
  	int globalMargin;

		double gridWidth;
		double gridHeight;
		double gridX1;
		double gridY1;
		double gridX2;
		double gridY2;
		double xSegments;
		double ySegments;
		double xSpacing;
		double ySpacing;	

		QColor gridColour;
		QColor axisColour;
		QColor dataColour;

		int gridLineWidth;
		int axisLineWidth;
		int dataLineWidth;

		QList<double> dataPointsList;
		QPointF * dataPoints;
		int numDataPoints;

		void calculateDataPoints();
};

#endif
